/*********************************************************
*Copyright (C), 2018, Shanghai Eastsoft Microelectronics Co., Ltd
*ļ:  ES_STL_StartUp.c
*  :  Eastsoft AE Team
*  :  V1.00
*  :  2022/08/25
*  :  CLASSB
*  ע:  FS030
 *
 * Copyright (C) Shanghai Eastsoft Microelectronics Co. Ltd. All rights reserved.
 *
 * SPDX-License-Identifier: Apache-2.0
 *
 * Licensed under the Apache License, Version 2.0 (the License); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an AS IS BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
**********************************************************/
#include "irqhandler.h"

void NMI_IRQHandler(void)
{
}

void HardFault_IRQHandler(void)
{
    while (1);
}

void SVC_IRQHandler(void)
{
}

void PendSV_IRQHandler(void)
{
}

void SysTick_IRQHandler(void)
{
    uint32_t RamTestResult;

    /* Verify TickCounter integrity */
    if ((TickCounter ^ TickCounterInv) == 0xFFFFFFFFuL)
    {
        TickCounter++;
        TickCounterInv = ~TickCounter;

        if (Current1sPeriod < 0xFFFFFFFF)
        {
            Current1sPeriod++;
            Current1sPeriodInv = ~Current1sPeriod;
        }

        if (TickCounter >= SYSTICK_100MS_TB)
        {
            /* Reset timebase counter */
            TickCounter = 0u;
            TickCounterInv = 0xFFFFFFFF;

            /* Set Flag read in main loop */
            TimeBaseFlag = 0xAAAAAAAAuL;
            TimeBaseFlagInv = 0x55555555uL;

            ISRCtrlFlowCnt += RAM_MARCHC_ISR_CALLER;
            __disable_irq();
            RamTestResult = STL_TranspMarchC();
            __enable_irq();
            ISRCtrlFlowCntInv -= RAM_MARCHC_ISR_CALLER;

            switch (RamTestResult)
            {
                case TEST_RUNNING:
                    break;

                case TEST_OK:
                    break;

                case TEST_FAILURE:
                case CLASS_B_DATA_FAIL:
                default:
#ifdef STL_VERBOSE_PRINTF
                    printf("\n\r >>>>>>>>>>>>>>>>>>>  RAM Error (March C- Run-time check)\n\r");
#endif
                    FailSafePOR();
                    break;
            }

            /* Do we reached the end of RAM test? */
            /* Verify 1st ISRCtrlFlowCnt integrity */
            if ((ISRCtrlFlowCnt ^ ISRCtrlFlowCntInv) == 0xFFFFFFFFuL)
            {
                if (RamTestResult == TEST_OK)           //RAM test finish
                {
                    ISRCtrlFlowCnt = 0u;
                    ISRCtrlFlowCntInv = 0xFFFFFFFFuL;
                }
            } /* End of control flow monitoring */
            else
            {
#ifdef STL_VERBOSE_PRINTF
                printf("\n\r Control Flow error in ISR \n\r");
#endif
                FailSafePOR();
            }
        }
    }
    else  /* Class B variable error on TickCounter */
    {
#ifdef STL_VERBOSE_PRINTF
        printf("\n\r Class B Error on TickCounter\n\r");
#endif
        FailSafePOR();
    }
}

/*********************************************************
: void WWDT_IRQHandler(void)
  : WWDT 1Sʱжϴ
ֵ: 
ֵ: 
ֵ: 
**********************************************************/
void WWDT_IRQHandler(void)
{
    if ((WWDT_GetITStatus() == SET) && (WWDT_GetFlagStatus() == SET))
    {
        WWDT_Clear();

        if (AbandonTimes != 0)
        {
            AbandonTimes--;
            AbandonTimesInv = AbandonTimes;
        }
        else
        {
            Last1sPeriod = Current1sPeriod;
            Last1sPeriodInv = ~Last1sPeriod;
        }

        Current1sPeriod = 0u;
        Current1sPeriodInv = 0xFFFFFFFFuL;
    }
}


/*********************************************************
: void T16N0_IRQHandler(void)
  : T16N0жϴ
ֵ: 
ֵ: 
ֵ: 
**********************************************************/
void T16N0_IRQHandler(void)
{
    uint32_t i;

    if (T16Nx_GetFlagStatus(T16N0, T16Nx_IT_MAT0) != RESET)
    {
        T16Nx_ClearITPendingBit(T16N0, T16Nx_IT_MAT0);

        for (i = 0; i < 30; i++)
        {
            ;
        }
    }
}
