/*********************************************************
*Copyright (C), 2018, Shanghai Eastsoft Microelectronics Co., Ltd
*ļ:  ES_STLclockrun.c
*  :  Eastsoft AE Team
*  :  V1.00
*  :  2022/08/25
*  :  This file contains the function returning a 16-bit CRC
*                      of part (or whole of) the Flash memory.
*  ע:  FS030
 *
 * Copyright (C) Shanghai Eastsoft Microelectronics Co. Ltd. All rights reserved.
 *
 * SPDX-License-Identifier: Apache-2.0
 *
 * Licensed under the Apache License, Version 2.0 (the License); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an AS IS BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
**********************************************************/
/* Includes ------------------------------------------------------------------*/
#include "lib_config.h"
#include "ES_STL_param.h"
#include "ES_STLclassBvar.h"

/* Private typedef -----------------------------------------------------------*/
/* Private define ------------------------------------------------------------*/
/* Private macro -------------------------------------------------------------*/
/* Private variables ---------------------------------------------------------*/
/* Private function prototypes -----------------------------------------------*/
/* Private functions ---------------------------------------------------------*/
ClockStatus STL_ClockFreqTest(void);
ClockStatus STL_CheckPeriod(uint32_t Period);
void STL_1sConfig(void);

/**
  * @brief  Initializes the SysTick for clock frequency measurement and
  *   main time base. The WWDT is reset and synchronized with the
  *   SysTick to have a direct comparison with reference period
  *   (WWDT counter is read during each SysTick interrupt).
  * @param :  None
  *   None
  * @retval : None
  */
void STL_1sConfig(void)
{
    WWDT_InitStruType x;

    x.WDT_Tms = 2000;
    x.WDT_IE = Enable;              /* WWDTжʹ */
    x.WDT_Rst = Disable;            /* WWDTλֹ */
    x.WDT_Clock = WWDT_CLOCK_WDT;   /* LRC */
    x.WDT_Win = WDT_WIN_50;         /* 50% WWDT_LOAD ж */
    WWDT_Init(&x);

    /* ʹWWDT */
    WWDT_Enable();

    NVIC_Init(NVIC_WWDT_IRQn, NVIC_Priority_0, Enable);
}

/* ---------------------------------------------------------------------------*/
/**
  * @brief  This function verifies that external clock source frequency
  *   did not change vs initial measurement (done with internal
  *   oscillators only.
  * @param :  None
  *   None
  * @retval : ClockStatus = (LSI_START_FAIL, HSE_START_FAIL,
  *   HSI_HSE_SWITCH_FAIL, TEST_ONGOING, EXT_SOURCE_FAIL,
  *   CLASS_B_VAR_FAIL, CTRL_FLOW_ERROR, FREQ_OK)
  */
ClockStatus STL_ClockFreqTest(void)
{
    ClockStatus Result = ClockStatus_TEST_FAIL;

    /* Verify first measure integrity and use it as reference */
    if ((Last1sPeriod ^ Last1sPeriodInv) != 0xFFFFFFFFuL)
    {
        Result = ClockStatus_TEST_FAIL;
    }
    else if ((Last1sPeriod < SYSTICK_1S_TB_MAX) && (Last1sPeriod > SYSTICK_1S_TB_MIN))
    {
        Result = ClockStatus_TEST_SUCCESSFUL;
    }
    else
    {
        Result = ClockStatus_TEST_FAIL;
    }

    return (Result);
}

/******************* (C) COPYRIGHT ESMicroelectronics *****END OF FILE****/
